.. _providers:

Available providers
===================

Description
^^^^^^^^^^^

Products from the following providers are made avaiable through ``eodag``:

* `sobloo <https://sobloo.eu/>`_: Airbus DIAS
* `usgs <https://earthexplorer.usgs.gov/>`_: U.S geological survey catalog for Landsat products
* `theia <https://theia.cnes.fr/atdistrib/rocket/>`_: French National Space Agency (CNES) catalog for Sentinel 2 products, Pleiades and Landsat products
* `peps <https://peps.cnes.fr/rocket/#/home>`_: French National Space Agency (CNES) catalog for Copernicus (Sentinel 1, 2, 3) products
* `aws_eos <https://eos.com/>`_: EOS search for Amazon public datasets
* `creodias <https://creodias.eu/>`_: CloudFerro DIAS
* `mundi <https://mundiwebservices.com/>`_: Atos DIAS
* `onda <https://www.onda-dias.eu/cms/>`_: Serco DIAS
* `astraea_eod <https://eod-catalog-svc-prod.astraea.earth/api.html>`_: Astraea Earth OnDemand STAC API
* `usgs_satapi_aws <https://landsatlook.usgs.gov/sat-api/>`_: USGS Landsatlook SAT API
* `earth_search and earth_search_cog <https://www.element84.com/earth-search/>`_: Element84 Earth Search
* `earth_search_gcs <https://cloud.google.com/storage/docs/public-datasets>`_: Element84 Earth Search and Google Cloud Storage download
* `ecmwf <https://www.ecmwf.int/>`_: European Centre for Medium-Range Weather Forecasts
* `cop_ads <https://ads.atmosphere.copernicus.eu>`_: Copernicus Atmosphere Data Store
* `cop_cds <https://cds.climate.copernicus.eu>`_: Copernicus Climate Data Store

Providers available through an external plugin:

* `SciHub / Copernicus Open Access Hub <https://scihub.copernicus.eu/userguide/WebHome>`_: available using
  `eodag-sentinelsat <https://github.com/CS-SI/eodag-sentinelsat>`_
